.. index:: single: runners; unittest2

===============================================================================
Python - unit2 - unittest2
===============================================================================

:abstract:

    Runs tests with the Python unittest2 0.5.1 package.

.. contents::

overview
-------------------------------------------------------------------------------

This runner was written to try interfacing with unittest2.  It seems
to work, but in the end we did not find unittest2 attractive enough
to be worth using.  We have py.test and nose.

You can find unittest2 at http://pypi.python.org/pypi/unittest2

